@@ -242,51 +242,6 @@ def build_parser():
             Default is "no".
         """,
     )
-    general.add_argument(
-        "--plugins",
-        action="store_true",
-        help="""
-            Print a list of all currently installed plugins.
-        """,
-    )
-    general.add_argument(
-        "--plugin-dir",
-        dest="plugin_dirs",
-        metavar="DIRECTORY",
-        action="append",
-        help="""
-            Load plugins from this directory.
-
-            Can be set multiple times to load plugins from multiple directories.
-        """,
-    )
-    general.add_argument(
-        "--plugin-dirs",
-        metavar="DIRECTORY",
-        type=comma_list,
-        action="extend",
-        help="""
-            Load plugins from a list of comma-separated directories. (deprecated)
-        """,
-    )
-    general.add_argument(
-        "--can-handle-url",
-        metavar="URL",
-        help="""
-            Check if Streamlink has a plugin that can handle the specified URL.
-
-            Status code is `0` on success, `1` on failure.
-
-            Useful for external scripting.
-        """,
-    )
-    general.add_argument(
-        "--can-handle-url-no-redirect",
-        metavar="URL",
-        help="""
-            Same as --can-handle-url, but without following redirects when looking up the URL.
-        """,
-    )
     general.add_argument(
         "--config",
         action="append",
@@ -344,7 +299,13 @@ def build_parser():
             See the Python standard library's `logging.Formatter` docs for more information about the logging format
             and the available `LogRecord` attributes. Streamlink's formatter uses the curly brace style.
 
-            The default format depends on the chosen log level (may include the `asctime` attribute).
+            The default format depends on the chosen log level.
+
+            For verbose levels (`trace` and `all`):
+
+            Default is "[{asctime}][{threadName}][{name}][{levelname}] {message}".
+
+            Otherwise:
 
             Default is "[{name}][{levelname}] {message}".
         """,
@@ -357,7 +318,13 @@ def build_parser():
 
             This formats the `LogRecord`'s `asctime` attribute via `strftime()`.
 
-            The default date format depends on the chosen log level (may include fractions).
+            The default date format depends on the chosen log level.
+
+            For verbose levels (`trace` and `all`):
+
+            Default is "%%H:%%M:%%S.%%f".
+
+            Otherwise:
 
             Default is "%%H:%%M:%%S".
         """,
@@ -391,9 +358,7 @@ def build_parser():
         "--quiet",
         action="store_true",
         help="""
-            Hide all log output.
-
-            Alias for --loglevel=none.
+            Suppress all console and log output, and also disable user prompts.
         """,
     )
     logging.add_argument(
@@ -407,6 +372,82 @@ def build_parser():
         """,
     )
 
+    plugin = parser.add_argument_group("Plugin options")
+    plugin.add_argument(
+        "--plugins",
+        action="store_true",
+        help="""
+            Print a list of all currently installed plugins.
+        """,
+    )
+    plugin.add_argument(
+        "--show-matchers",
+        metavar="PLUGIN",
+        help="""
+            Show the list of matchers of a specific plugin (URL regex pattern with opt. priority and opt. name).
+
+            The output is a human-readable pseudo YAML format. Please use --json when reading matcher data programmatically.
+        """,
+    )
+    plugin.add_argument(
+        "--can-handle-url",
+        metavar="URL",
+        help="""
+            Check if Streamlink has a plugin that can handle the specified URL.
+
+            Status code is `0` on success, `1` on failure.
+
+            Useful for external scripting.
+        """,
+    )
+    plugin.add_argument(
+        "--can-handle-url-no-redirect",
+        metavar="URL",
+        help="""
+            Same as --can-handle-url, but without following redirects when looking up the URL.
+        """,
+    )
+    plugin.add_argument(
+        "--no-plugin-cache",
+        action="store_true",
+        default=None,
+        help="""
+            Disable I/O of the plugin key-value store.
+
+            If disabled, plugins won't be able to load or store data like cookies, authentication data, etc.
+            The data which is loaded or stored depends on each plugin implementation.
+        """,
+    )
+    plugin.add_argument(
+        "--no-plugin-sideloading",
+        action="store_true",
+        help="""
+            Disable automatic sideloading of third-party plugins from the default location.
+
+            See the plugin-sideloading documentation for where third-party plugins are loaded from.
+        """,
+    )
+    plugin.add_argument(
+        "--plugin-dir",
+        dest="plugin_dirs",
+        metavar="DIRECTORY",
+        action="append",
+        help="""
+            Load additional plugins from this directory.
+
+            Can be set multiple times to load plugins from multiple directories.
+        """,
+    )
+    plugin.add_argument(
+        "--plugin-dirs",
+        metavar="DIRECTORY",
+        type=comma_list,
+        action="extend",
+        help="""
+            Load additional plugins from a list of comma-separated directories. (deprecated)
+        """,
+    )
+
     network = parser.add_argument_group("Network arguments")
     network.add_argument(
         "--interface",
@@ -718,6 +759,7 @@ def build_parser():
     )
     output.add_argument(
         "--fs-safe-rules",
+        metavar="{POSIX,Windows}",
         choices=["POSIX", "Windows"],
         type=str,
         help="""
@@ -743,6 +785,15 @@ def build_parser():
             When using --output or --record, always write to file even if it already exists (overwrite).
         """,
     )
+    output.add_argument(
+        "--skip",
+        action="store_true",
+        help="""
+            When using --output or --record, never write to file if it already exists (don't prompt).
+
+            Takes precedence over --force.
+        """,
+    )
     output.add_argument(
         "--progress",
         metavar="{yes,force,no}",
@@ -795,13 +846,16 @@ def build_parser():
     stream.add_argument(
         "--retry-streams",
         metavar="DELAY",
-        type=num(float, gt=0),
+        type=num(float, ge=0),
         help="""
             Retry fetching the list of available streams until streams are found
-            while waiting `DELAY` second(s) between each attempt. If unset, only one
-            attempt will be made to fetch the list of streams available.
+            while waiting `DELAY` second(s) between each attempt.
 
-            The number of fetch retry attempts can be capped with --retry-max.
+            The number of retry attempts can be capped with --retry-max.
+            A default value of ``1`` is implied for non-zero values of --retry-max.
+
+            If both --retry-streams and --retry-max are set to `0`, then only one attempt will be made
+            to fetch the list of available streams. This is the default behavior.
         """,
     )
     stream.add_argument(
@@ -809,10 +863,10 @@ def build_parser():
         metavar="COUNT",
         type=num(int, ge=0),
         help="""
-            When using --retry-streams, stop retrying the fetch after `COUNT` retry
-            attempt(s). Fetch will retry infinitely if `COUNT` is zero or unset.
+            Stop fetching the list of available streams after `COUNT` retry attempt(s).
 
-            If --retry-max is set without setting --retry-streams, the delay between retries will default to 1 second.
+            A value of `0` makes Streamlink fetch streams indefinitely if --retry-streams is set to a non-zero value.
+            If --retry-streams is unset, then the default delay between fetching available streams is 1 second.
         """,
     )
     stream.add_argument(
@@ -1411,6 +1465,7 @@ def build_parser():
 # NOTE: arguments with `action=store_{true,false}` must set `default=None`
 _ARGUMENT_TO_SESSIONOPTION: list[tuple[str, str, Callable[[Any], Any] | None]] = [
     # generic arguments
+    ("no_plugin_cache", "no-plugin-cache", None),
     ("locale", "locale", None),
     # network arguments
     ("interface", "interface", None),
@@ -1480,7 +1535,7 @@ def setup_session_options(session: Streamlink, args: argparse.Namespace):
 def setup_plugin_args(session: Streamlink, parser: ArgumentParser):
     """Adds plugin argument data to the argument parser."""
 
-    plugin_args = parser.add_argument_group("Plugin options")
+    plugin_args = parser.add_argument_group("Plugin-specific options")
     for pname, arguments in session.plugins.iter_arguments():
         group = parser.add_argument_group(pname.capitalize(), parent=plugin_args)
 
